package com.jdwsoftware.wfh.control;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.applet.AudioClip;
import java.applet.Applet;

/**
 * <p><b>Title</b>: Woody's Fishing Hole</p>
 * <p><b>Description</b>: Educational Fishing Game</p>
 * <p><b>Copyright</b>: Copyright (C) 2003 JDW Software, LLC</p>
 * <p><b>Company</b>: JDW Software, LLC</p>
 *
 * <p>This class sets up the main frame, loads the base classes,
 *    handles events, etc.</p>
 *
 * @author <a href="mailto:jdw@jdwsoftware.com">Jim Woodgate</a>
 * @version $Revision: 1.6 $
 */

/*
 * This file is part of Woodys Fishing Hole.
 *
 * Woodys Fishing Hole is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * Woodys Fishing Hole is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Woodys Fishing Hole; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

public class MainFrame extends JFrame {
  private static final String COPYRIGHT = com.jdwsoftware.util.Copyright.COPYRIGHT;
  private static final String VERSION = "$Id: MainFrame.java,v 1.6 2003/12/10 05:29:47 jdw Exp $";

  JPanel contentPane;
  JMenuBar jMenuBar1 = new JMenuBar();
  JMenu jMenuFile = new JMenu();
  JMenuItem jMenuFileExit = new JMenuItem();
  JLabel statusBar = new JLabel();
  JMenu jMenuGame = new JMenu();
  JMenuItem jMenuHelpAbout = new JMenuItem();
  JMenu jMenuHelp = new JMenu();
  JMenu jMenuGameFish = new JMenu();
  JMenuItem jMenuItemGameFish3 = new JMenuItem();
  JMenuItem jMenuItemGameFish4 = new JMenuItem();
  JMenuItem jMenuItemGameFish5 = new JMenuItem();
  JMenuItem jMenuItemGameFish6 = new JMenuItem();
  JMenuItem jMenuItemGameFish7 = new JMenuItem();
  JMenu jMenuGameType = new JMenu();
  JMenuItem jMenuItemGameTypeColor = new JMenuItem();
  JMenuItem jMenuItemGameTypeNumber = new JMenuItem();
  JMenuItem jMenuItemGameTypeMath = new JMenuItem();
  GameComponent gameComponent = new GameComponent();

  //Construct the frame
  public MainFrame() {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
    BGMusicThread musicThread = new BGMusicThread();
    musicThread.setPriority(musicThread.getPriority() - 2 > Thread.MIN_PRIORITY
                            ? musicThread.getPriority() - 2
                            : Thread.MIN_PRIORITY);
    musicThread.start();
  }
  //Component initialization
  private void jbInit() throws Exception  {
    contentPane = (JPanel) this.getContentPane();
    contentPane.setLayout(null);

    this.setCursor(null);
    gameComponent.setDoubleBuffered(true);
    gameComponent.addMouseListener(new MainFrame_gameComponent_mouseAdapter(this));
    gameComponent.addMouseMotionListener(new MainFrame_gameComponent_mouseMotionAdapter(this));
    gameComponent.setLayout(null);
    gameComponent.setStatusBar(statusBar);
    jMenuItemGameTypeColor.addActionListener(new MainFrame_jMenuItemGameType_actionAdapter(this));
    jMenuItemGameTypeNumber.addActionListener(new MainFrame_jMenuItemGameType_actionAdapter(this));
    jMenuItemGameTypeMath.addActionListener(new MainFrame_jMenuItemGameType_actionAdapter(this));
    jMenuItemGameFish3.addActionListener(new MainFrame_jMenuItemGameFish_actionAdapter(this));
    jMenuItemGameFish4.addActionListener(new MainFrame_jMenuItemGameFish_actionAdapter(this));
    jMenuItemGameFish5.addActionListener(new MainFrame_jMenuItemGameFish_actionAdapter(this));
    jMenuItemGameFish6.addActionListener(new MainFrame_jMenuItemGameFish_actionAdapter(this));
    jMenuItemGameFish7.addActionListener(new MainFrame_jMenuItemGameFish_actionAdapter(this));
    jMenuHelpAbout.addActionListener(new MainFrame_jMenuHelpAbout_ActionAdapter(this));
    this.getContentPane().add(gameComponent);

    this.setSize(new Dimension(640, 550));
    this.setState(Frame.NORMAL);
    this.setTitle("Woodys Fishing Hole");
    statusBar.setBounds(new Rectangle(-1, 478, 640, 22));
    jMenuFile.setText("File");
    jMenuFileExit.setText("Exit");
    jMenuFileExit.addActionListener(new MainFrame_jMenuFileExit_ActionAdapter(this));
    jMenuGame.setText("Game");
    jMenuHelpAbout.setText("About");
    jMenuHelp.setText("Help");
    jMenuGameFish.setText("Fish");
    jMenuItemGameFish3.setText("3");
    jMenuItemGameFish4.setText("4");
    jMenuItemGameFish5.setText("5");
    jMenuItemGameFish6.setText("6");
    jMenuItemGameFish7.setText("7");
    jMenuGameType.setText("Type");
    jMenuItemGameTypeColor.setText("Colors");
    jMenuItemGameTypeNumber.setText("Numbers");
    jMenuItemGameTypeMath.setText("Math");
    contentPane.setPreferredSize(new Dimension(4, 15));
    jMenuFile.add(jMenuFileExit);
    jMenuBar1.add(jMenuFile);
    jMenuBar1.add(jMenuGame);
    jMenuBar1.add(jMenuHelp);
    this.setJMenuBar(jMenuBar1);
    jMenuHelp.add(jMenuHelpAbout);
    jMenuGame.add(jMenuGameFish);
    jMenuGame.add(jMenuGameType);
    jMenuGameFish.add(jMenuItemGameFish3);
    jMenuGameFish.add(jMenuItemGameFish4);
    jMenuGameFish.add(jMenuItemGameFish5);
    jMenuGameFish.add(jMenuItemGameFish6);
    jMenuGameFish.add(jMenuItemGameFish7);
    jMenuGameType.add(jMenuItemGameTypeColor);
    jMenuGameType.add(jMenuItemGameTypeNumber);
    jMenuGameType.add(jMenuItemGameTypeMath);
    contentPane.add(statusBar, null);
  }

  //File | Exit action performedg
  public void jMenuFileExit_actionPerformed(ActionEvent e) {
    System.exit(0);
  }
  //Help | About action performed
  public synchronized void jMenuHelpAbout_actionPerformed(ActionEvent e) {
    MainFrame_AboutBox dlg = new MainFrame_AboutBox(this);
    Dimension dlgSize = dlg.getPreferredSize();
    Dimension frmSize = getSize();
    Point loc = getLocation();
    dlg.setLocation((frmSize.width - dlgSize.width) / 2 + loc.x, (frmSize.height - dlgSize.height) / 2 + loc.y);
    dlg.setModal(true);
    dlg.pack();
    gameComponent.pauseGame(true);
    dlg.show();
    gameComponent.pauseGame(false);
  }
  //Overridden so we can exit when window is closed
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      jMenuFileExit_actionPerformed(null);
    }
  }

  void gameComponent_mouseMoved(MouseEvent e) {
    gameComponent.notifyMouseMoved(e.getPoint());
  }

  void gameComponent_mouseClicked(MouseEvent e) {
    gameComponent.notifyMouseClicked(e.getPoint());
  }

  void jMenuItemGameType_actionPerformed(ActionEvent e) {
    gameComponent.setGameType(e.getActionCommand());
  }

  void jMenuItemGameFish_actionPerformed(ActionEvent e) {
    int numFish = 3;
    try { numFish = Integer.parseInt(e.getActionCommand()); } catch (Exception ex) { /* NOOP */}
    gameComponent.setNumFish(numFish);
  }

}

class MainFrame_jMenuFileExit_ActionAdapter implements ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuFileExit_ActionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuFileExit_actionPerformed(e);
  }
}

class MainFrame_gameComponent_mouseMotionAdapter extends java.awt.event.MouseMotionAdapter {
  MainFrame adaptee;

  MainFrame_gameComponent_mouseMotionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void mouseMoved(MouseEvent e) {
    adaptee.gameComponent_mouseMoved(e);
  }
}

class MainFrame_gameComponent_mouseAdapter extends java.awt.event.MouseAdapter {
  MainFrame adaptee;

  MainFrame_gameComponent_mouseAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void mouseClicked(MouseEvent e) {
    adaptee.gameComponent_mouseClicked(e);
  }
}

class MainFrame_jMenuItemGameType_actionAdapter implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItemGameType_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItemGameType_actionPerformed(e);
  }
}

class MainFrame_jMenuItemGameFish_actionAdapter implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItemGameFish_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItemGameFish_actionPerformed(e);
  }
}

class BGMusicThread extends Thread {

  public void run() {
    AudioClip clip = Applet.newAudioClip(MainFrame.class.getResource("PeanujakesReel.mid"));
    clip.loop();
  }
}

class MainFrame_jMenuHelpAbout_ActionAdapter implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuHelpAbout_ActionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuHelpAbout_actionPerformed(e);
  }
}
