package com.jdwsoftware.wfh.model;

import javax.swing.JComponent;
import java.awt.Image;

/**
 * <p><b>Title</b>: Woody's Fishing Hole</p>
 * <p><b>Description</b>: Educational Fishing Game</p>
 * <p><b>Copyright</b>: Copyright (C) 2003 JDW Software, LLC</p>
 * <p><b>Company</b>: JDW Software, LLC</p>
 *
 * <p>This is the abstract class that all the various game types extend.
 *    The basic premise is that a game has an answer which is shown near
 *    the top of the screen, and many questions.  Each fish will get a
 *    question (and hopefully at least one fish will have the correct
 *    answer.. :)</p>
 *
 * <p>For many games the questions and answers are the same (blue box to
 *    blue box or the number 8 to the number 8).  However the MathGame
 *    will display a math problem for the question and numbers for the
 *    answers.  Other things like pictures matching to words or upper case
 *    letters to lower case letters are easily added also.</p>
 *
 * @author <a href="mailto:jdw@jdwsoftware.com">Jim Woodgate</a>
 * @version $Revision: 1.5 $
 */

/*
 * This file is part of Woodys Fishing Hole.
 *
 * Woodys Fishing Hole is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * Woodys Fishing Hole is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Woodys Fishing Hole; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

public abstract class GameType {
  private static final String COPYRIGHT = com.jdwsoftware.util.Copyright.COPYRIGHT;
  private static final String VERSION = "$Id: GameType.java,v 1.5 2003/11/22 03:47:15 jdw Exp $";

  protected JComponent _caller;
  protected static final int WIDTH = 50;
  protected static final int HEIGHT = 50;
  protected static final int BORDER = 5;

  /**
   * Default constructor, note the component that is going to use
   * this game needs to register itself so images can be created.
   *
   * @param caller
   */
  public GameType(JComponent caller) {
    super();
    _caller = caller;
  }

  /**
   * In general the width of all the questions, because these will
   * actually go on the fish, this method probably shouldn't be
   * overriden unless you really know what you are doing.
   *
   * @return Default question width
   */
  public int getWidth() {
    return WIDTH;
  }

  /**
   * In general the height of all the questions, because these will
   * actually go on the fish, this method probably shouldn't be
   * overriden unless you really know what you are doing.
   *
   * @return Default question height
   */
  public int getHeight() {
    return HEIGHT;
  }

  /**
   * Get the question image this is to be displayed on the
   * passed component
   *
   * @return an image of the question
   */
  public abstract Image getQuestion();

  /**
   * Get the string representation of the answer to getQuestion()
   *
   * @return String answer
   */
  public abstract String getAnswer();

  /**
   * Get a set of all possible answers.  This is a set of string
   * answers.
   *
   * @return Set of all possible answers
   */
  public abstract String[] getValidAnswers();

  /**
   * Given an answer string, get the corresponding image to put on
   * the fish.
   *
   * @param s Answer
   * @return Image for that answer
   */
  public abstract Image getAnswer(String s);

  /**
   * Call new question to generate a new question and answer
   */
  public abstract void newQuestion();
}
