package com.jdwsoftware.wfh.model;

import javax.swing.JComponent;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.Color;
import java.awt.Font;

import java.util.Hashtable;
import java.util.Random;

/**
 * <p><b>Title</b>: Woody's Fishing Hole</p>
 * <p><b>Description</b>: Educational Fishing Game</p>
 * <p><b>Copyright</b>: Copyright (C) 2003 JDW Software, LLC</p>
 * <p><b>Company</b>: JDW Software, LLC</p>
 *
 * <p>This game diplays an simple math problem, a number 1-9 a
 *    plus sign and another number 1-9.  The answers are the sum
 *    of the two numbers</p>
 *
 * @author <a href="mailto:jdw@jdwsoftware.com">Jim Woodgate</a>
 * @version $Revision: 1.8 $
 */

/*
 * This file is part of Woodys Fishing Hole.
 *
 * Woodys Fishing Hole is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * Woodys Fishing Hole is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Woodys Fishing Hole; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

public class MathGame extends GameType {
  private static final String COPYRIGHT = com.jdwsoftware.util.Copyright.COPYRIGHT;
  private static final String VERSION = "$Id: MathGame.java,v 1.8 2003/12/02 04:22:32 jdw Exp $";

  private static final String[] ANSWERS = new String[] {" 0"," 1"," 2"," 3",
                                                        " 4"," 5"," 6"," 7",
                                                        " 8"," 9","10","11",
                                                        "12","13","14","15",
                                                        "16","17","18"};

  private Hashtable _images;
  private Image     _answerImage;
  private Font      _bigFont;

  private String _question;
  private static Random r = new Random();

  public MathGame(JComponent caller) {
    super(caller);
    _answerImage = _caller.createImage(getWidth()*3/2, getHeight());
    Graphics g = _answerImage.getGraphics();
    g.setColor(Color.black);
    g.fillRect(0,0, getWidth()*3/2, getHeight());

    _images = new Hashtable();

    _bigFont = new java.awt.Font("Monospaced", 1, 32);
    for (int i=0; i<ANSWERS.length; i++) {
      String key = ANSWERS[i];
      Image image = _caller.createImage(getWidth(), getHeight());
      g = image.getGraphics();
      g.setColor(Color.black);
      g.fillRect(0,0,getWidth(),getHeight());
      g.setColor(Color.white);
      g.fillRect(BORDER, BORDER, getWidth()-2*BORDER, getHeight()-2*BORDER);
      g.setColor(Color.black);
      g.setFont(_bigFont);
      g.drawString(key, BORDER*3/2-1, BORDER+_bigFont.getSize());
      _images.put(key, image);
    }
    newQuestion();
  }

  public synchronized void newQuestion() {
    int x = r.nextInt(9)+1;
    int y = r.nextInt(9)+1;
    _question = x+y<10 ? " "+(x+y) : ""+(x+y);
    Graphics g = _answerImage.getGraphics();
    g.setColor(Color.white);
    g.fillRect(BORDER, BORDER, getWidth()*3/2-2*BORDER, getHeight()-2*BORDER);
    g.setColor(Color.black);
    g.setFont(_bigFont);
    g.drawString(""+x+"+"+y, BORDER*3/2-1, BORDER+_bigFont.getSize());
  }

  public Image getQuestion() {
    return _answerImage;
  }

  public String getAnswer() {
    return _question;
  }

  public String[] getValidAnswers() {
    return ANSWERS;
  }

  public Image getAnswer(String s) {
    return (Image)_images.get(s);
  }

}
